==> plugin-android-3.2.4-sources.jar: com/zoyi/channel/plugin/android/activity/chat/view/form/FormButtonView.java <==
package com.zoyi.channel.plugin.android.activity.chat.view.form;

import android.content.Context;
import android.graphics.drawable.GradientDrawable;
import android.support.annotation.Nullable;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.widget.LinearLayout;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnFormMessageClickListener;
import com.zoyi.channel.plugin.android.model.ActionInput;
import com.zoyi.channel.plugin.android.global.PrefSupervisor;
import com.zoyi.channel.plugin.android.selector.ColorSelector;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;

/**
 * Created by jerry on 2018. 6. 11..
 */

public class FormButtonView extends LinearLayout implements View.OnTouchListener {

  private Context context;

  private MaskableFrameLayout leftRoundHeaderLayout;
  private MaskableFrameLayout roundHeaderLayout;

  private View leftRoundHeader;
  private View roundHeader;
  private CHTextView buttonText;

  @Nullable
  private OnFormMessageClickListener onClickListener;

  private ActionInput actionInput;

  private int COLOR_DARK_80;
  private int COLOR_WHITE;

  private boolean clicked;

  public FormButtonView(Context context, ActionInput actionInput, @Nullable OnFormMessageClickListener onClickListener) {
    super(context);
    init(context, actionInput, onClickListener);
  }

  private void init(Context context, ActionInput actionInput, @Nullable OnFormMessageClickListener clickListener) {
    this.context = context;
    this.actionInput = actionInput;

    View view = LayoutInflater.from(context).inflate(R.layout.ch_plugin_view_form_button, this);

    leftRoundHeaderLayout = view.findViewById(R.id.ch_layout_form_message_head);
    roundHeaderLayout = view.findViewById(R.id.ch_layout_form_message_content);

    leftRoundHeader = view.findViewById(R.id.ch_view_form_message_head_top);
    roundHeader = view.findViewById(R.id.ch_view_form_message_content_top);

    buttonText = view.findViewById(R.id.ch_text_form_message_complete);
    buttonText.setText(actionInput.getValue(PrefSupervisor.getPluginLanguage(context)));

    leftRoundHeader.setVisibility(GONE);
    roundHeader.setVisibility(VISIBLE);

    COLOR_DARK_80 = ContextCompat.getColor(context, R.color.ch_dark_80);
    COLOR_WHITE = ContextCompat.getColor(context, R.color.ch_white);

    clicked = false;

    setButtonText(actionInput);
    setListener(clickListener);
    changeColor(false);
  }

  private void setButtonText(ActionInput actionInput) {
    buttonText.setMaxLines(2);
    buttonText.setEllipsize(TextUtils.TruncateAt.END);
    buttonText.setText(actionInput.getValue(PrefSupervisor.getPluginLanguage(context)));
    buttonText.setTextColor(COLOR_DARK_80);
  }

  private void setListener(@Nullable OnFormMessageClickListener clickListener) {
    setOnTouchListener(this);
    this.onClickListener = clickListener;
  }

  @Override
  public boolean onTouch(View v, MotionEvent event) {
    switch (event.getAction()) {

      case MotionEvent.ACTION_DOWN:
        changeColor(!clicked);
        break;

      case MotionEvent.ACTION_CANCEL:
        changeColor(clicked);
        break;

      case MotionEvent.ACTION_UP:
        clicked = !clicked;

        if (onClickListener != null) {
          onClickListener.onFormMessageClick(actionInput);
        }
        break;
    }
    return true;
  }

  private void changeColor(boolean isClicked) {
    GradientDrawable drawable = new GradientDrawable();
    drawable.setColor(isClicked ? ColorSelector.getBackgroundColor() : COLOR_WHITE);
    drawable.setStroke((int) Utils.dpToPx(context, 1f), isClicked ? ColorSelector.getBackgroundColor() : COLOR_DARK_80);
    drawable.setCornerRadius((int) Utils.dpToPx(context, 15f));

    roundHeader.setBackgroundDrawable(drawable);
    buttonText.setBackgroundDrawable(drawable);

    buttonText.setTextColor(isClicked ? COLOR_WHITE : COLOR_DARK_80);
  }
}

==> plugin-android-5.2.2-sources.jar: com/zoyi/channel/plugin/android/activity/chat/view/form/FormButtonView.java <==
package com.zoyi.channel.plugin.android.activity.chat.view.form;

import android.content.Context;
import android.graphics.drawable.GradientDrawable;
import android.support.annotation.Nullable;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.widget.LinearLayout;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnMessageContentClickListener;
import com.zoyi.channel.plugin.android.model.ActionInput;
import com.zoyi.channel.plugin.android.selector.ColorSelector;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.util.message_format.MessageParser;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;

/**
 * Created by jerry on 2018. 6. 11..
 */

public class FormButtonView extends LinearLayout implements View.OnTouchListener {

  private Context context;

  private MaskableFrameLayout leftRoundHeaderLayout;
  private MaskableFrameLayout roundHeaderLayout;

  private View leftRoundHeader;
  private View roundHeader;
  private CHTextView buttonText;

  @Nullable
  private OnMessageContentClickListener onMessageContentClickListener;

  private ActionInput actionInput;

  @Nullable
  private String actionType;

  private int COLOR_DARK_80;
  private int COLOR_WHITE;

  private boolean clicked;

  public FormButtonView(
      Context context,
      @Nullable String actionType,
      ActionInput actionInput,
      @Nullable OnMessageContentClickListener onMessageContentClickListener) {
    super(context);
    init(context, actionType, actionInput, onMessageContentClickListener);
  }

  private void init(
      Context context,
      @Nullable String actionType,
      ActionInput actionInput,
      @Nullable OnMessageContentClickListener onMessageContentClickListener) {
    this.context = context;
    this.actionType = actionType;
    this.actionInput = actionInput;

    View view = LayoutInflater.from(context).inflate(R.layout.ch_plugin_view_form_button, this);

    leftRoundHeaderLayout = view.findViewById(R.id.ch_layout_form_message_head);
    roundHeaderLayout = view.findViewById(R.id.ch_layout_form_message_content);

    leftRoundHeader = view.findViewById(R.id.ch_view_form_message_head_top);
    roundHeader = view.findViewById(R.id.ch_view_form_message_content_top);

    buttonText = view.findViewById(R.id.ch_text_form_message_complete);
    buttonText.setText(actionInput.getValue());

    leftRoundHeader.setVisibility(GONE);
    roundHeader.setVisibility(VISIBLE);

    COLOR_DARK_80 = ContextCompat.getColor(context, R.color.ch_dark_80);
    COLOR_WHITE = ContextCompat.getColor(context, R.color.ch_white);

    clicked = false;

    setButtonText(actionInput);
    setListener(onMessageContentClickListener);
    changeColor(false);
  }

  private void setButtonText(ActionInput actionInput) {
    buttonText.setMaxLines(2);
    buttonText.setEllipsize(TextUtils.TruncateAt.END);
    buttonText.setTextColor(COLOR_DARK_80);
    if (MessageParser.get() != null) {
      buttonText.setText(MessageParser.get().parse(actionInput.getValue()));
    } 
  }

  private void setListener(@Nullable OnMessageContentClickListener onMessageContentClickListener) {
    setOnTouchListener(this);
    this.onMessageContentClickListener = onMessageContentClickListener;
  }

  @Override
  public boolean onTouch(View v, MotionEvent event) {
    switch (event.getAction()) {

      case MotionEvent.ACTION_DOWN:
        changeColor(!clicked);
        break;

      case MotionEvent.ACTION_CANCEL:
        changeColor(clicked);
        break;

      case MotionEvent.ACTION_UP:
        clicked = !clicked;

        if (onMessageContentClickListener != null) {
          onMessageContentClickListener.onFormClick(actionType, actionInput);
        }
        break;
    }
    return true;
  }

  private void changeColor(boolean isClicked) {
    GradientDrawable drawable = new GradientDrawable();
    drawable.setColor(isClicked ? ColorSelector.getBackgroundColor() : COLOR_WHITE);
    drawable.setStroke((int) Utils.dpToPx(context, 1f), isClicked ? ColorSelector.getBackgroundColor() : COLOR_DARK_80);
    drawable.setCornerRadius((int) Utils.dpToPx(context, 15f));

    roundHeader.setBackgroundDrawable(drawable);
    buttonText.setBackgroundDrawable(drawable);

    buttonText.setTextColor(isClicked ? ColorSelector.getTextColor() : COLOR_DARK_80);
  }
}
